package com.ruoyi.system.mapper;

import java.util.List;
import com.ruoyi.system.domain.IntegralOrder;

/**
 * 积分订单Mapper接口
 * 
 * @author ruoyi
 * @date 2025-05-13
 */
public interface IntegralOrderMapper 
{
    /**
     * 查询积分订单
     * 
     * @param id 积分订单主键
     * @return 积分订单
     */
    public IntegralOrder selectIntegralOrderById(Long id);

    /**
     * 查询积分订单列表
     * 
     * @param integralOrder 积分订单
     * @return 积分订单集合
     */
    public List<IntegralOrder> selectIntegralOrderList(IntegralOrder integralOrder);

    /**
     * 新增积分订单
     * 
     * @param integralOrder 积分订单
     * @return 结果
     */
    public int insertIntegralOrder(IntegralOrder integralOrder);

    /**
     * 修改积分订单
     * 
     * @param integralOrder 积分订单
     * @return 结果
     */
    public int updateIntegralOrder(IntegralOrder integralOrder);

    /**
     * 删除积分订单
     * 
     * @param id 积分订单主键
     * @return 结果
     */
    public int deleteIntegralOrderById(Long id);

    /**
     * 批量删除积分订单
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteIntegralOrderByIds(Long[] ids);
}
